@@ -59,7 +59,13 @@ def combine_intermediate_file(intermediate_participant_path, date_in_study):
         csv_path_list = sorted(glob(os.path.join(date_folder_path, target_file_pattern)))  # file name
 
         csv_path = csv_path_list[0]
-        df_day = pd.read_csv(csv_path)
+
+        try:
+            df_day = pd.read_csv(csv_path)
+        except AttributeError:
+            print("AttributeError (phone lock) : " + csv_path)
+            quit()
+
         if df_day.shape[0] > 0:
             df_day['Participant_ID'] = [participant_id] * df_day.shape[0]
             df_logs_combined = pd.concat([df_logs_combined, df_day])
